@@ -22,7 +22,27 @@ from ._utils import (
     _edge_list_to_adjacency_list,
     _get_connected_components,
 )
-from ._node_layout import get_fruchterman_reingold_layout, _clip_to_frame
+
+
+# monkeypatch repulsive force
+def _get_fr_repulsion(distance, direction, k):
+    """Compute repulsive forces.
+
+    This is a variant of the implementation in the original FR
+    algorithm, in as much as repulsion only acts between fixed nodes
+    and mobile nodes, not between fixed nodes and other fixed nodes.
+    """
+    total_mobile = distance.shape[1]
+    distance = distance[total_mobile:]
+    direction = direction[total_mobile:]
+    magnitude = k**2 / distance
+    vectors = direction * magnitude[..., None]
+    return np.sum(vectors, axis=0)
+
+import netgraph._node_layout
+netgraph._node_layout._get_fr_repulsion = _get_fr_repulsion
+from netgraph._node_layout import get_fruchterman_reingold_layout, _clip_to_frame
+
 
 # for profiling with kernprof/line_profiler
 try:
@@ -240,7 +260,7 @@ def get_curved_edge_paths(edges, node_positions,
         k = np.sqrt(area / float(total_nodes))
         k *= 0.1
 
-    edge_to_control_points = _initialize_control_points(edges, node_positions, k)
+    edge_to_control_points = _initialize_control_points(edges, node_positions, k, scale)
 
     control_point_positions = _initialize_control_point_positions(
         edge_to_control_points, node_positions, selfloop_radius, origin, scale)
@@ -258,14 +278,15 @@ def get_curved_edge_paths(edges, node_positions,
     return edge_to_path
 
 
-def _initialize_control_points(edges, node_positions, k):
+def _initialize_control_points(edges, node_positions, k, scale):
     """Represent each edge with string of control points."""
     edge_to_control_points = dict()
     for start, stop in edges:
         if start != stop:
-            distance = np.linalg.norm(node_positions[stop] - node_positions[start], axis=-1)
-            total_control_points = distance / np.pi / k # approximating the arc length with a half-circle
-            total_control_points = max(int(total_control_points), 1) # ensure that there is at least one point
+            distance = np.linalg.norm(node_positions[stop] - node_positions[start], axis=-1) / np.linalg.norm(scale)
+            # total_control_points = distance * np.pi / k # approximating the arc length with a half-circle
+            total_control_points = distance * 10
+            total_control_points = min(max(int(total_control_points), 1), 5) # ensure that there are at least one point but no more than 5
             edge_to_control_points[(start, stop)] = [uuid4() for _ in range(total_control_points)]
         else: # self-loop
             edge_to_control_points[(start, stop)] = [uuid4() for _ in range(5)]
@@ -378,10 +399,13 @@ def _optimize_control_point_positions(
     expanded_node_positions = control_point_positions.copy() # TODO: may need deepcopy here
     expanded_node_positions.update(node_positions)
 
+    # increase size of nodes so that there is a bit more clearance between edges and nodes
+    node_size = {node : 2 * size for node, size in node_size.items()}
+
     with warnings.catch_warnings():
         warnings.filterwarnings("ignore", category=UserWarning)
 
-        expanded_node_positions = get_fruchterman_reingold_layout(
+        expanded_node_positions = get_fruchterman_reingold_layout.__wrapped__(
             expanded_edges,
             node_positions      = expanded_node_positions,
             scale               = scale,
