@@ -130,7 +130,7 @@ def get_layout_for_multiple_components(edges, components, layout_function,
     return node_positions
 
 
-def _get_packed_component_bboxes(components, origin, scale, power=0.8, pad_by=0.05):
+def _get_packed_component_bboxes(components, origin, scale, power=0.8, pad_by=0.1):
     """Partition the canvas given by origin and scale into bounding boxes, one for each component.
 
     Use rectangle packing to tightly arrange bounding boxes.
@@ -179,8 +179,8 @@ def _get_packed_component_bboxes(components, origin, scale, power=0.8, pad_by=0.
         from matplotlib.patches import Rectangle
         fig, ax = plt.subplots(1,1)
         for bbox in bboxes:
-            ax.add_artist(Rectangle(bbox[:2], bbox[2], bbox[3], color=np.random.rand(3)))
-        plt.show()
+            ax.add_artist(Rectangle(bbox[:2], bbox[2], bbox[3], color=np.random.rand(3), zorder=-1))
+        # plt.show()
 
     return bboxes
 
@@ -642,8 +642,8 @@ def get_sugiyama_layout(edges, origin=(0,0), scale=(1,1), node_size=3, total_ite
     positions = _rescale_to_frame(np.array(positions), np.array(origin), np.array(scale))
 
     # place roots on top, leaves on bottom
-    positions -= np.max(positions, axis=0)
-    positions *= -1
+    positions[:, 1] -= origin[1] + scale[1]
+    positions[:, 1] *= -1
 
     return dict(zip(nodes, positions))
 
